@@ -21,20 +21,20 @@ class OperationPropertiesSchema:
             extra = Extra.forbid
 
     class SingleValue(BaseModel):
-        data: str
+        data: Any
 
         class Config:
             extra = Extra.forbid
 
     class MultipleValue(BaseModel):
-        data: Tuple[str, ...]
+        data: Tuple[Any, ...]
 
         class Config:
             extra = Extra.forbid
 
     class RangeValue(BaseModel):
-        start: str
-        end: str
+        start: Any
+        end: Any
 
         class Config:
             extra = Extra.forbid
@@ -76,8 +76,8 @@ class OperationSchemas:
                 for attr, value in cls.__dict__.items()
                 if isinstance(value, OperationSchemaSpec) and value.jsonschema == jsonschema
             )
-        except StopIteration:
-            raise ValueError("OperationSchema not found")
+        except StopIteration as err:
+            raise ValueError("OperationSchema not found") from err
 
 
 class ParamOperation:
@@ -193,6 +193,14 @@ class ParamOperation:
         ),
         properties_schema=OperationSchemas.NO_VALUE.jsonschema,
     )
+    EMPTY_STRING = ParamOperationSpecs(
+        uid="crystal.topics.data.param-operation.empty-string",
+        i18n=I18n(
+            name="cons-data-table-sort-operation-label-empty-string",
+            description="crystal.topics.data.param-operation.empty-string.i18n.description",
+        ),
+        properties_schema=OperationSchemas.NO_VALUE.jsonschema,
+    )
 
     @classmethod
     def from_uid(cls, uid: str) -> ParamOperationSpecs:
@@ -204,5 +212,5 @@ class ParamOperation:
                 for attr, value in cls.__dict__.items()
                 if isinstance(value, ParamOperationSpecs) and value.uid == uid.lower()
             )
-        except StopIteration:
-            raise ValueError(f"Invalid ParamOperation uid={uid}")
+        except StopIteration as err:
+            raise ValueError(f"Invalid ParamOperation uid={uid}") from err
