@@ -1,10 +1,12 @@
+from __future__ import annotations
+
 import abc
 from enum import Enum
-from typing import Any, List, Optional, Union
+from typing import List, Optional, Union
 
-from pydantic import BaseModel, Field, root_validator, validator
+from pydantic import BaseModel, Field, root_validator
 
-from igenius_adapters_sdk.entities import data, params, uri
+from igenius_adapters_sdk.entities import data, uri
 
 
 class JoinType(str, Enum):
@@ -13,13 +15,8 @@ class JoinType(str, Enum):
     RIGHT_OUTER = "right-outer"
 
 
-class CriteriaType(str, Enum):
-    AND = "and"
-    OR = "or"
-
-
 class JoinPart(BaseModel):
-    from_: "From"
+    from_: From
     on: uri.AttributeUri
 
 
@@ -34,46 +31,34 @@ From = Union[uri.CollectionUri, Join]
 JoinPart.update_forward_refs()
 
 
-class Expression(BaseModel):
-    attribute_uri: uri.AttributeUri
-    operator: str
-    value: Any
-
-    @validator("operator")
-    def check_uid_existance(cls, v):
-        params.ParamOperation.from_uid(v)
-        return v
-
-    @validator("value")
-    def validate_operation_schema(cls, v, values):
-        if "operator" in values:
-            schema = params.ParamOperation.from_uid(values["operator"]).properties_schema
-            operation_schema = params.OperationSchemas.from_jsonschema(schema)
-            if v is None:
-                v = {}
-            if not isinstance(v, dict):
-                key = next(iter(params.OperationPropertiesSchema.SingleValue.__fields__))
-                v = {key: v}
-            return operation_schema.model(**v).dict()
-        return v
+class AliasableQueryType(str, Enum):
+    WITH = "with_query"
+    TEMP = "temporary_table"
+    STATEMENT = "statement"
 
 
-class MultiExpression(BaseModel):
-    criteria: CriteriaType
-    expressions: List[Union["MultiExpression", Expression]]
+class AliasableQuery(BaseModel):
+    alias: str
+    query: BaseQuery
+    type: AliasableQueryType = AliasableQueryType.WITH
 
 
-WhereExpression = Union[MultiExpression, Expression]
-# see https://pydantic-docs.helpmanual.io/usage/postponed_annotations/#self-referencing-models
-MultiExpression.update_forward_refs()
+Subqueries = List[AliasableQuery]
 
 
 class BaseQuery(BaseModel, abc.ABC):
-    from_: From
-    where: Optional[WhereExpression]
+    from_: Optional[From]
+    where: Optional[data.WhereExpression]
     order_by: Optional[List[data.OrderByAttribute]]
-    limit: int = Field(None, ge=0)
-    offset: int = Field(None, ge=0)
+    limit: Optional[int] = Field(None, ge=0)
+    offset: Optional[int] = Field(None, ge=0)
+    # If a template is provided, the previous fields will be ignored
+    template: Optional[data.NamedSqlTemplate] = None
+    subqueries: Optional[Subqueries] = None
+
+
+# see https://github.com/samuelcolvin/pydantic/issues/1298
+AliasableQuery.update_forward_refs()
 
 
 class SelectQuery(BaseQuery):
@@ -81,12 +66,15 @@ class SelectQuery(BaseQuery):
     distinct: bool = False
 
 
+Aggregations = List[Union[data.CustomColumnAttribute, data.AggregationAttribute, data.StaticValueAttribute]]
+
+
 class AggregationQuery(BaseQuery):
-    aggregations: List[Union[data.AggregationAttribute, data.StaticValueAttribute]]
+    aggregations: Aggregations
 
 
 class GroupByQuery(BaseQuery):
-    aggregations: List[Union[data.AggregationAttribute, data.StaticValueAttribute]]
+    aggregations: Aggregations
     groups: List[data.BinningAttribute]
     bin_interpolation: Optional[bool] = None
 
