@@ -17,7 +17,9 @@ __all__ = [
 
 OptionalInt = Optional[int]
 RE_MATCH_COLLECTION_NAME = re.compile(r"" + environ.get("IGENIUS_ADAPTER_SDK_RE_MATCH_COLLECTION_NAME", r"^\S+$"))
-RE_MATCH_ALL_BUT_NEW_LINES_AND_TABS = re.compile(r"" + environ.get("IGENIUS_ADAPTER_SDK_RE_MATCH_ATTRIBUTE_NAME", r"^[\S ]+$"))
+RE_MATCH_ALL_BUT_NEW_LINES_AND_TABS = re.compile(
+    r"" + environ.get("IGENIUS_ADAPTER_SDK_RE_MATCH_ATTRIBUTE_NAME", r"^[\S ]+$")
+)
 
 
 class Uid(str):
